@@ -487,3 +487,9 @@ class TestAVMetadataFormat(TestCase):
     @min_os_level("12.0")
     def testConstants12_0(self):
         self.assertIsInstance(AVFoundation.AVMetadataQuickTimeMetadataKeyIsMontage, str)
+
+    @min_os_level("15.0")
+    def testConstants15_0(self):
+        self.assertIsInstance(
+            AVFoundation.AVMetadataQuickTimeMetadataKeyFullFrameRatePlaybackIntent, str
+        )
